@@ -310,7 +310,7 @@ void Game::redraw()
       {
 	//if (Playerlist::getActiveplayer()->getType() == Player::HUMAN ||
 	    //GameScenario::s_hidden_map == false)
-	  smallmap->draw();
+	  smallmap->draw(Playerlist::getActiveplayer());
       }
 }
 
@@ -1126,6 +1126,7 @@ void Game::on_player_died(Player *player)
     player_died.emit(player);
 }
 
+      
 void Game::on_fight_started(Fight &fight)
 {
   
@@ -1141,7 +1142,7 @@ void Game::on_fight_started(Fight &fight)
 
   //don't show the battle if we're ai and we're on a hidden map
   bool ai_attacking_on_hidden_map = false;
-  if (fight.getDefenders().front()->getOwner()->getType() != Player::HUMAN &&
+  if (fight.getAttackers().front()->getOwner()->getType() != Player::HUMAN &&
       GameScenario::s_hidden_map == true)
     ai_attacking_on_hidden_map = true;
 
@@ -1149,10 +1150,11 @@ void Game::on_fight_started(Fight &fight)
       attacking_observable_player) && !ai_attacking_neutral &&
       !ai_attacking_on_hidden_map)
     {
+      Vector<int> pos = fight.getAttackers().front()->getPos();
       if (GameScenario::s_hidden_map == false)
-	smallmap->center_view_on_tile(fight.getAttackers().front()->getPos(),
-				      true);
-      bigmap->setFighting(LocationBox(fight.getAttackers().front()->getPos()));
+	smallmap->center_view_on_tile(pos, true);
+      LocationBox box = Fight::calculateFightBox(fight);
+      bigmap->setFighting(box);
       bigmap->draw();
       fight_started.emit(fight);
       bigmap->setFighting(LocationBox(Vector<int>(-1,-1)));
