@@ -98,7 +98,7 @@ void GameBigMap::select_active_stack()
   if (!stack->getPath()->checkPath(stack))
     {
       //error handling is required here, up to now we only barf on cerr
-      cerr << _("original path of stack was blocked\n");
+      cerr << "original path of stack was blocked\n";
     }
 
   stack_selected.emit(stack);
@@ -180,7 +180,7 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 
 	  int dist = stack->getPath()->calculate(stack, p);
 	  if (dist == -2)
-	    cerr << _("error calculating path!");
+	    cerr << "error calculating path!";
 
 	  Vector<int>* dest = 0;
 	  if (!stack->getPath()->empty())
@@ -273,7 +273,10 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 		}
 	      else if (Ruin *r = Ruinlist::getInstance()->getObjectAt(tile))
 		{
-		  ruin_queried (r, false);
+		  if ((r->isHidden() == true && 
+		       r->getOwner() == Playerlist::getActiveplayer()) ||
+		      r->isHidden() == false)
+		    ruin_queried (r, false);
 		}
 	      else if (Temple *t = Templelist::getInstance()->getObjectAt(tile))
 		{
@@ -591,7 +594,13 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 		d_cursor = GraphicsCache::ROOK;
 	    }
 	  else if (t->getBuilding() == Maptile::RUIN)
-	    d_cursor = GraphicsCache::RUIN;
+	    {
+	      Ruin *ruin = Ruinlist::getInstance()->getObjectAt(tile);
+	      if (ruin->isHidden() == true && ruin->getOwner() == active)
+		d_cursor = GraphicsCache::RUIN;
+	      else if (ruin->isHidden() == false)
+		d_cursor = GraphicsCache::RUIN;
+	    }
 	  else if (t->getBuilding() == Maptile::TEMPLE)
 	    d_cursor = GraphicsCache::RUIN;
 	}
@@ -676,6 +685,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
       //subsequent dragging
       //alright.  calculate the path, and show it but don't move
       //be careful that we don't drop our path on bad objects
+      //also, slide the whole view if we drag out of view
       if (is_inside(view, tile) == false)
 	{
 	  Vector<int> delta(0,0);
@@ -749,8 +759,12 @@ void GameBigMap::after_draw()
       // draw all waypoints
       Uint32 pathcount = 0;
       bool canMoveThere = true;
+      list<Vector<int>*>::iterator end = stack->getPath()->end();
+      //if we're dragging, we don't draw the last waypoint circle
+      if (stack->getPath()->size() > 0 && mouse_state == DRAGGING_STACK)
+	end--;
       for (list<Vector<int>*>::iterator it = stack->getPath()->begin();
-	   it != stack->getPath()->end(); it++)
+	   it != end; it++)
 	{
 	  size_t wpsize = 40; //waypoint images are always 40x40
 	  pos = tile_to_buffer_pos(**it);
@@ -775,14 +789,34 @@ void GameBigMap::after_draw()
 
 	}
 
+      if (mouse_state == DRAGGING_STACK)
+	{
+	  list<Vector<int>*>::iterator it = stack->getPath()->end();
+	  it--;
+	  //this is where the ghosted army unit picture goes.
+	  Army *a = *stack->begin();
+	  SDL_Surface *tmp = gc->getArmyPic(a);
+	  size_t wpsize = tmp->w;
+	  pos = tile_to_buffer_pos(**it);
+	  SDL_Rect r1, r2;
+	  r1.y = 0;
+	  r1.w = r1.h = tmp->w; 
+	  int offset = (tilesize - tmp->w) / 2;
+	  if (offset < 0)
+	    offset = 0;
+	  r2.x = pos.x + offset;
+	  r2.y = pos.y + offset;
+	  r2.w = r2.h = wpsize;
+	  SDL_BlitSurface(tmp, 0, buffer, &r2);
+	}
     }
 
-  if (stack)
+  if (stack && d_fighting.getPos() == Vector<int>(-1,-1))
     {
       // draw the selection
       Vector<int> p = stack->getPos();
       if (is_inside(buffer_view, Vector<int>(p.x, p.y)) &&
-	  FogMap::isFogged(p) == false)
+	  FogMap::isFogged(p, Playerlist::getActiveplayer()) == false)
 	{
 	  static int bigframe = -1;
 	  static int smallframe = -1;
@@ -827,9 +861,17 @@ void GameBigMap::after_draw()
       SDL_Rect r;
       r.x = p.x;
       r.y = p.y;
-      r.w = r.h = tilesize;
+      r.w = r.h = tilesize * d_fighting.getSize();
       SDL_Surface *tmp = gc->getExplosionPic();
-      SDL_BlitSurface(tmp, 0, buffer, &r);
+      SDL_SetAlpha(tmp, 0, 0);
+      SDL_PixelFormat* fmt = tmp->format;
+      SDL_Surface *explode = SDL_CreateRGBSurface
+	(SDL_SWSURFACE, d_fighting.getSize() * tilesize, 
+	 d_fighting.getSize() * tilesize,
+       fmt->BitsPerPixel, fmt->Rmask, fmt->Gmask, fmt->Bmask, fmt->Amask);
+      SDL_SoftStretch(tmp, 0, explode, 0);
+      SDL_BlitSurface(explode, 0, buffer, &r);
+      SDL_FreeSurface(explode);
     }
 }
 
