@@ -80,6 +80,7 @@
 #include "diplomacy-dialog.h"
 #include "stack-info-dialog.h"
 #include "timed-message-dialog.h"
+#include "destination-dialog.h"
 
 #include "ucompose.hpp"
 #include "defs.h"
@@ -308,6 +309,12 @@ GameWindow::GameWindow()
 			 sigc::mem_fun(*this, &GameWindow::on_resign_activated));
     xml->connect_clicked("production_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_production_activated));
+    xml->connect_clicked("cities_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_production_activated));
+    xml->connect_clicked("build_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_production_activated));
+    xml->connect_clicked("vectoring_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_vectoring_activated));
     xml->connect_clicked("levels_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_levels_activated));
     xml->connect_clicked("ruin_report_menuitem",
@@ -1285,6 +1292,31 @@ void GameWindow::on_resign_activated()
   return;
 }
 
+void GameWindow::on_vectoring_activated()
+{
+  City *city;
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
+
+  if (currently_selected_stack)
+    {
+      Vector<int> pos = currently_selected_stack->getPos();
+      city = Citylist::getInstance()->getNearestVisibleFriendlyCity(pos);
+    }
+  else
+    city = Citylist::getInstance()->getFirstCity(Playerlist::getActiveplayer());
+
+  if (!city)
+    return;
+  bool see_all = true;
+  DestinationDialog d(city, &see_all);
+
+  d.set_parent_window(*window.get());
+  d.run();
+  d.hide();
+  return;
+}
+
 void GameWindow::on_production_activated()
 {
   City *city;
@@ -1299,6 +1331,9 @@ void GameWindow::on_production_activated()
   else
     city = Citylist::getInstance()->getFirstCity(Playerlist::getActiveplayer());
 
+  if (!city)
+    return;
+
   on_city_visited(city);
   return;
 }
@@ -1624,13 +1659,9 @@ void GameWindow::on_player_died(Player *player)
       player->getType() == Player::HUMAN)
     {
       s += "\n";
-      s += _("No further human resistance is possible");
+      s += _("No further human resistance is possible\nbut the battle will continue!");
       s += "\n";
-      s += _("but the battle will continue!");
-      s += "\n";
-      s += _("Press `CTRL-P' to stop the war");
-      s += "\n";
-      s += _("and visit the sites of thy old battles.");
+      s += _("Press `CTRL-P' to stop the war\nand visit the sites of thy old battles.");
     }
 
   TimedMessageDialog dialog(*window.get(), s, 30);
