@@ -15,10 +15,12 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
-#include "tilestyle.h"
-#include "defs.h"
 #include <iostream>
 
+#include "tilestyle.h"
+#include "defs.h"
+
+std::string TileStyle::d_tag = "tilestyle";
 using namespace std;
 
 TileStyle::TileStyle()
@@ -51,7 +53,7 @@ bool TileStyle::save(XML_Helper *helper)
   bool retval = true;
 
   char *idstr = NULL;
-  retval &= helper->openTag("tilestyle");
+  retval &= helper->openTag(d_tag);
   if (asprintf (&idstr, "0x%02x", d_id) != -1)
     {
       retval &= helper->saveData("id", idstr);
